#
# spec file for package gdk-pixbuf
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# When updating the binary version, do not forget to also update baselibs.conf
%define gdk_pixbuf_binary_version 2.10.0

Name:           gdk-pixbuf
VCS: https://src.suse.de/pool/gdk-pixbuf#e6402d02d80a4841b69d0c6c6322a9994d5418c7
Version:        2.42.10
Release:        2.12
Summary:        An image loading library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://www.gnome.org/

# A filefrom the test suite is correctly identified by clamav to be a
# malicious BC.Gif.Exploit.Agent-1425366.Agent. This is an intentional part of
# the test suite to ensure it has no negative side effects. Change the Source0
# from tar.xz to zip to bypass clamav scanning on SLE.
Source0:        %{name}-%{version}.zip
Source1:        macros.gdk-pixbuf
Source2:        README.SUSE
Source3:        gdk-pixbuf-rpmlintrc
Source99:       baselibs.conf

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docutils
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  meson >= 0.55.3
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libpng)

%description
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package -n libgdk_pixbuf-2_0-0
Summary:        An image loading library
# Provide %%{name} to make the lang package installable
Group:          System/Libraries
Requires(post): gdk-pixbuf-query-loaders
Conflicts:      gtk2 < 2.21.3
Provides:       %{name} = %{version}

%description  -n libgdk_pixbuf-2_0-0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package -n typelib-1_0-GdkPixbuf-2_0
Summary:        Introspection bindings for gdk-pixbuf
Group:          System/Libraries

%description -n typelib-1_0-GdkPixbuf-2_0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package provides the GObject Introspection bindings for gdk-pixbuf.

%package -n typelib-1_0-GdkPixdata-2_0
Summary:        Introspection bindings for gdk-pixdata
Group:          System/Libraries

%description -n typelib-1_0-GdkPixdata-2_0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package provides the GObject Introspection bindings for gdk-pixdata.

%package query-loaders
Summary:        Utility to create a cache of gdk-pixbuf loaders
Group:          System/X11/Utilities

%description query-loaders
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains the utility to create the cache file needed for
loadable modules.

%package thumbnailer
Summary:        System helper creating thumbnails
Group:          System/X11/Utilities
Supplements:    libgdk_pixbuf-2_0-0

%description thumbnailer
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains the thumbnailer utility.

%package devel
Summary:        Development files for gdk-pixbuf, an image loading library
Group:          Development/Languages/C and C++
Requires:       libgdk_pixbuf-2_0-0 = %{version}
Requires:       typelib-1_0-GdkPixbuf-2_0 = %{version}
Requires:       typelib-1_0-GdkPixdata-2_0 = %{version}

%description devel
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains the development files for gdk-pixbuf.

%lang_package

%prep
%setup -c -T -q
unzip -P gecko %{SOURCE0}
%if "%{_lib}" == "lib64"
cp -a %{SOURCE2} .
%endif
%autopatch -p1

%build
%meson \
	-Dinstalled_tests=false \
	%{nil}
%meson_build

%install
%meson_install
rm -rf %{buildroot}{%{_libexecdir},%{_datadir}}/installed-tests/
%find_lang %{name}
touch %{buildroot}%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache
%if "%{_lib}" == "lib64"
  mv %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders-64
  mv %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders.1 %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders-64.1
%endif
# Install rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
cp %{SOURCE1} %{buildroot}%{_rpmmacrodir}

#############################################################################
# Note: when updating scriptlets, don't forget to also update baselibs.conf #
#############################################################################

# Convenient %%define for the scriplets
%if "%{_lib}" == "lib64"
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders-64
%else
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders
%endif
%define _gdk_pixbuf_query_loaders_update_cache %{_gdk_pixbuf_query_loaders} --update-cache

%post -n libgdk_pixbuf-2_0-0
/sbin/ldconfig
%if 0
# In case libgdk_pixbuf-2_0-0 gets installed before gdk-pixbuf-query-loaders,
# we don't want to fail. So we make the call to gdk-pixbuf-query-loaders
# dependent on the existence of the binary. This is why we also have a %%post
# for gdk-pixbuf-query-loaders.
%endif
if test -f %{_gdk_pixbuf_query_loaders}; then
  %{_gdk_pixbuf_query_loaders_update_cache}
fi

%post query-loaders
%if 0
# If we install gdk-pixbuf-query-loaders for the first time, then we should run
# it in case libgdk_pixbuf-2_0-0 was installed first (ie, if
# %%{_libdir}/gdk-pixbuf-2.0/%%{gdk_pixbuf_binary_version} already exists) which
# means gdk-pixbuf-query-loaders couldn't run there.
%endif
if [ $1 = 1 ]; then
  test -d %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
  if test $? -eq 0; then
    %{_gdk_pixbuf_query_loaders_update_cache}
  fi
fi

%if 0
# No need to call gdk-pixbuf-query-loaders in postun:
# - if it's an upgrade, it will have been called in post
# - if it's an uninstall, we don't care about this anymore
%endif

%postun -n libgdk_pixbuf-2_0-0 -p /sbin/ldconfig

%files -n libgdk_pixbuf-2_0-0
%license COPYING
%doc NEWS
%if "%{_lib}" == "lib64"
%doc README.SUSE
%endif
%{_libdir}/libgdk_pixbuf-2.0.so.0*
%dir %{_libdir}/gdk-pixbuf-2.0
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders
%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders/*.so
%ghost %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache

%files -n typelib-1_0-GdkPixbuf-2_0
%{_libdir}/girepository-1.0/GdkPixbuf-2.0.typelib

%files -n typelib-1_0-GdkPixdata-2_0
%{_libdir}/girepository-1.0/GdkPixdata-2.0.typelib

%files query-loaders
%{_bindir}/gdk-pixbuf-query-loaders*
%{_mandir}/man1/gdk-pixbuf-query-loaders*.1*

%files thumbnailer
%{_bindir}/gdk-pixbuf-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/gdk-pixbuf-thumbnailer.thumbnailer

%files devel
%{_bindir}/gdk-pixbuf-csource
%{_bindir}/gdk-pixbuf-pixdata
%{_mandir}/man1/gdk-pixbuf-csource.1*
%{_includedir}/gdk-pixbuf-2.0
%{_libdir}/pkgconfig/gdk-pixbuf-2.0.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/GdkPixbuf-2.0.gir
%{_datadir}/gir-1.0/GdkPixdata-2.0.gir
%{_rpmmacrodir}/macros.gdk-pixbuf

%files lang -f %{name}.lang

%changelog
* Wed Oct 26 2022 bjorn.lie@gmail.com
- Update to version 2.42.10:
  + Search for rst2man.py.
  + Update the memory size limit for JPEG images.
  + Updated translations.
- Drop patch fixed upstream (with different limit):
  + 0001-jpeg-Increase-memory-limit-for-loading-image-data.patch
* Tue Aug 30 2022 mgorse@suse.com
- Add 0001-jpeg-Increase-memory-limit-for-loading-image-data.patch:
  fix loading of larger images (glgo#GNOME/gdk-pixbuf#216).
* Mon Aug 15 2022 dmueller@suse.com
- avoid bashism in baselibs postscript (bsc#1195391)
* Tue Aug  9 2022 bjorn.lie@gmail.com
- Update to version 2.42.9:
  + Fix the check for maximum value of LZW initial code size
    (boo#1194633 CVE-2021-44648).
  + Use CMake for dependencies on Windows/MSVC.
  + Add option for building tests.
  + Move man pages to reStructuredText.
  + Disable relocation when built as a static libary on Windows.
  + Update wrap file for libjpeg-turbo.
  + Limit the memory size when loading image data.
- Add docutils and pkgconfig(gi-docgen) BuildRequires: New
  dependencies.
* Fri Mar 18 2022 bjorn.lie@gmail.com
- Update to version 2.42.8 (boo#1201826):
  + Clear the pixbuf's memory buffer to avoid returning
    uninitialized memory.
  + Turn GdkPixbufModule functions into typed callbacks.
  + tiff: Use non-deprecated C99 integer types.
  + gif: Check for overflow when compositing or clearing frames.
  + Change png/jpeg/tiff build options from boolean to feature.
  + jpeg: Do not rely on UB around setjmp/longjmp.
  + Build fixes.
  + Documentation fixes.
  + Security fixes: CVE-2021-46829.
  + Updated translations.
- Stop passing options to meson that just follow upstream default,
  just rely on upstream providing sane defaults, apart from where
  we want to deviate.
* Thu Nov  4 2021 bjorn.lie@gmail.com
- Stop passing no longer used nor recognized options jasper=false
  and x11=false to meson, fails the build when using meson 0.60.x.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Jul 30 2021 yfjiang@suse.com
- Drop gdk-pixbuf-bsc1180393-CVE-2020-29385.patch on SLE and Leap
  15.4: fixed upstream.
* Wed Apr 14 2021 rpm@fthiessen.de
- Update to stable 2.42.6
  + Yield gtk_doc option value in subprojects
  + Always initialise locale on thumbnailer startup
  + Add fallback subproject for libjpeg
  + Use type:array for the builtin_loaders option
  + Default to using builtin png and jpeg loaders
* Sat Mar 27 2021 dimstar@opensuse.org
- Disable building of docs: creates a cycle with python:
  + Drop python3-gi-docgen BuildRequires.
  + Pass gtk_doc=false to meson
* Sun Mar 21 2021 dimstar@opensuse.org
- Update to version 2.42.4:
  + Make enum type registration thread safe.
  + Do not install skipped test files.
  + Fix GIF initialization.
  + Always run GIF loader tests.
  + Fix leaks discovered via ASan.
  + Expose GdkPixbufLoader API via introspection.
  + Fix revert-to-previous first frame behaviour for GIF files.
  + Link to libintl if needed.
  + Improve support for using gdk-pixbuf as a subproject.
  + Fix build with GModule disabled.
  + Use gi-docgen to generate the API reference from introspection
    data.
- Replace gtk-doc BuildRequires with python3-gi-docgen: follow
  upstreams port.
- As a workaround to
  https://gitlab.gnome.org/GNOME/gdk-pixbuf/-/issues/177, delete
  the installed gi-docgen program files.
* Thu Jan  7 2021 zcjia@suse.com
- Add gdk-pixbuf-bsc1180393-CVE-2020-29385.patch:
  gif: Fix LZW decoder accepting invalid LZW code. (bsc#1180393)
* Tue Dec  8 2020 dimstar@opensuse.org
- Update to version 2.42.2:
  + Requre Meson 0.55.3.
  + Improve the PNG save operation.
  + Fix leak in the error path of the XPM loader.
  + Fix loading GIF without a GCE rendering color 0.
  + Fix invalid LZW codes in the GIF loader (CVE-2020-29385).
* Mon Nov  9 2020 dimstar@opensuse.org
- Udpate to version 2.42.0:
  + Remove the libjasper JPEG2000 loader.
  + Split the gdk-pixbuf-xlib library to a separate repository.
  + Fix cppcheck 'shifting signed 32-bit value warning',
  + Fix memory leaks in pixops error paths,
  + Improve internal consistency of loaders,
  + Skip bytes during JPEG incremental load.
  + Check for overflows.
  + Let the test suite cope with missing loaders.
  + Check for mmap failure.
  + Fix UB in the XPM loader.
  + Speed up alpha scaling pixop.
  + Add the `gtk_doc` configuration option, and deprecate `docs`.
  + Add the `introspection` configuration option, and remove `gir`.
  + Handle truncated PNMs more gracefully.
  + Clean up GIF loader code.
  + Fix colormap handling in GIF.
- Drop gdk-pixbuf-boo1174307-io-gif-overflow.patch: fixed upstream.
- Replace meson parameters, following upstream changes:
  + -Ddocs=true => -Dgtk_doc=true.
  + -Dgir=true => -Dintrospection=enabled.
* Mon Jul 27 2020 zcjia@suse.com
- Add gdk-pixbuf-boo1174307-io-gif-overflow.patch: Avoid overflows
  by checking the memset length argument (boo#1174307).
- Raise dependency glib-2.0 version.
* Mon Feb 24 2020 yfjiang@suse.com
- A file tests/test-images/gif-test-suite/max-width.gif from the
  test suite is correctly identified by clamav to be a malicious
  BC.Gif.Exploit.Agent-1425366.Agent. This is an intentional part
  of the test suite to ensure it has no negative side effects.
  On SLE, the package is built with clamav scanning, which then
  prevents a successful build. This change repacks the source
  package to a password-protected zip to bypass the clamav scanning
  for SLE (bsc#1159337), with following update:
  + Download upstream tarball through source service
  + Add pre_checkin.sh to convert tarball to zip file
  + Update spec-file to use the zip file as main source
* Thu Jan 30 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Wed Nov 27 2019 bjorn.lie@gmail.com
- Drop pkgconfig(x11) BuildRequires and pass -Dx11=false to meson.
  No longer build x11 support, that is now split out in it's own
  compat package.
* Tue Oct  8 2019 bjorn.lie@gmail.com
- Update to version 2.40.0:
  + Allow creating a GdkPixbuf instance without any property.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 2.39.2:
  + Add gdk_pixbuf_init_modules() for applications with GdkPixbuf
    loader modules in a separate directory.
  + Add subproject fallback for dependencies.
  + Handle large XPM without crashing.
  + Use the appropriate gdk-pixbuf-query-loaders on install.
  + Disable deprecation warnings introduced by GLib 2.62.
  + Escape GIF version in error messages.
  + Render GIF frames on demand.
* Mon Sep  9 2019 bjorn.lie@gmail.com
- Update to version 2.38.2:
  + build: Remove unnecessary argument.
  + gif: Suppress last deprecation warning.
  + tests:
  - Disable deprecation warnings for GTimeVal.
  - Add test for issue 95.
  - Add test image for invalid XPM data.
  + Disable deprecation warnings for GTimeVal.
  + Use the monotonic clock instead of wall one.
  + xpm:
  - Fail when XPM file doesn't contain enough data.
  - Simplify error path.
  - Sanity check XPM file dimensions.
* Wed May  8 2019 dimstar@opensuse.org
- Move RPM macros to %%_rpmmacrodir.
* Thu Feb 28 2019 bjorn.lie@gmail.com
- Update to version 2.38.1:
  + Fix OOM in JPEG2000 loader.
  + Fix thumbnailing of animated GIFs.
  + Multiple improvements to the GIF loader.
  + Fix introspection generation.
  + Fix error handling in PNG loader.
  + Improve reproducibility of the build.
  + Speed up saving PNG files.
  + Add variables in the pkg-config files for binary utilities.
  + Build fixes.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 2.38.0:
  + Stable release.
  + Documentation fixes.
* Wed Aug 22 2018 bjorn.lie@gmail.com
- Update to version 2.37.92:
  + Ensure that GdkPixbuf's storage is safely handled.
  + Add test case for buffer overflow in pixdata loader.
* Sun Jul  8 2018 bjorn.lie@gmail.com
- Pass all options to meson, ensure we build gdk-pixbuf with the
  features we want.
* Wed Jun 20 2018 luc14n0@linuxmail.org
- Update to version 2.37.0:
  + Plug a memory leak when using GBytes (bgo#787626).
  + Fix introspection annotations (bgo#789935).
  + Fix OOB error when dithering (bgo#748211).
  + Drop the MMX assembly optimizations for pixops.
  + Improve compatibility for the post-install script (bgo#795705).
  + Expose the dimensions of the original image from
    GdkPixbufLoader (bgo#778517).
  + Improve thumbnailer implementation (bgo#778517).
  + Generate separate introspection data for GdkPixdata API
    (glgo#GNOME/gdk-pixbuf#72).
  + Deprecate GDK_INTERP_HYPER (glgo#GNOME/gdk-pixbuf#3).
- Pass installed_tests as false to meson to make sure we don't ship
  unnecessary tests.
- Add typelib-1_0-GdkPixdata GI subpackage and require it on the
  devel package, following upstream changes.
* Tue Apr 10 2018 luc14n0@linuxmail.org
- Update to version 2.36.12:
  + gif, ico, jpeg, tiff, icns: various fixes (bgo#778584,
    bgo#779012, bgo#753605, bgo#779020, bgo#779016).
  + Implement async loading without threads.
  + Updated translations.
- Rename with_docs meson option to docs, following usptream change.
- Drop fixed upstream patches:
  gdk-pixbuf-bgo779012-ico-overflow.patch,
  gdk-pixbuf-gif-negative-array-indexes.patch,
  gdk-pixbuf-gif-uninitialized-variable.patch,
  gdk-pixbuf-tiff-overflow.patch and
  gdk-pixbuf-icns-handle-short-blocklen.patch.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan  5 2018 mgorse@suse.com
- Add gdk-pixbuf-bgo779012-ico-overflow.patch: fix a potential
  integer overflow (boo#1027026 CVE-2017-6312).
- Add gdk-pixbuf-gif-negative-array-indexes.patch and
  gdk-pixbuf-gif-uninitialized-variable.patch: protect against
  access to negative array indexes (BGO#778584).
- Add gdk-pixbuf-tiff-overflow.patch: avoid overflow during size
  computation (bgo#779020).
- Add gdk-pixbuf-icns-handle-short-blocklen.patch: protect against
  short block length when reading icns (boo#1027024
  CVE-2017-6313).
* Tue Oct  3 2017 luc14n0@linuxmail.org
- Update to version 2.36.11:
  + Build:
  - Fix tiff loader build (bgo#786342).
  - Prefer newer libpng (bgo#786035).
  + Use a free reference images for tests (bgo#787050).
  + gif: fail quickly if image dimensions are too big (bgo#785973).
  + xlib: Avoid an out-of-bounds error on bigendian (bgo#775896).
  + Updated translations.
- Drop u_contrib-gdk-pixbuf-xlib-Fix-rgb888amsb.patch: fixed
  upstream.
- Add gdk-pixbuf-rpmlintrc: filter gdk-pixbuf-devel.*: W:
  non-conffile-in-etc /etc/rpm/macros.gdk-pixbuf.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 2.36.10:
  + build: meson build improvements.
  + build: win32 build fixes.
  + tests: show error before failing (bgo#786259).
  + Updated translations.
* Fri Sep  8 2017 jengelh@inai.de
- Update summaries and RPM categories.
* Tue Aug 22 2017 dimstar@opensuse.org
- Migrate to meosn build system:
  + Add meson BuildRequires: new dependency.
  + Add xsltproc, gdk-doc and docbook-xsl-stylesheets
    BuildRequires: new dependencies, as gtk-doc and man pages are
    no longer pre-built.
  + Replace configure, make, make_install calls for respective
    meson, meson_build and meson_install macros.
- Drop libjasper-devel BuildRequires: drop JPEG2000 support: it is
  not enabled per default by upstream.
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 2.36.9:
  + build: meson build improvements.
  + OS X: don't require shared-mime-info (bgo#786167).
  + gif: fix a coverity warning (bgo#785696).
  + build: make queryloaders output reproducible (bgo#783592).
  + Updated translations.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 2.36.8:
  + jpeg: restore grayscale image support (bgo#785171).
  + bmp: Tighten image dimension checks (bgo#776694).
  + ico: Fixo icon quality sorting (bgo#785447).
  + Various other leak and overflow fixes (bgo#765094, bgo#783538,
    bgo#778204).
  + Add some assertion to help static analysis (bgo#778943).
  + Remove support for building on various obsolete platforms.
  + Updated translations.
* Tue Jul 18 2017 zaitor@opensuse.org
- Update to version 2.36.7:
  + Add tests for recent bug fixes.
  + ico, bmp, tiff: avoid integer overflows (bgo#776040,
    bgo#776694, bgo#780269).
  + jpeg: error out if wrong # of channels (bgo#784866).
  + Misc.bugfixes (bgo#784583).
  + Support mimetypes: image/wmf, image/emf.
  + Updated translations.
- Drop gdk-pixbuf-cve-2017-2862-jpeg-channels.patch and
  gdk-pixbuf-cve-2017-2870-tiff-mul-overflow.patch: Fixed upstream.
* Sun Jul 16 2017 hpj@suse.com
- Add fixes for crashes, taken from upstream git (CVE-2017-2862,
  CVE-2017-2870, bgo#784866, bgo#780269):
  gdk-pixbuf-cve-2017-2862-jpeg-channels.patch
  gdk-pixbuf-cve-2017-2870-tiff-mul-overflow.patch
* Wed May 10 2017 dimstar@opensuse.org
- Supplement libgdk_pixbuf-2_0-0 by the thumbnailers (boo#1037100).
* Sun Mar 26 2017 zaitor@opensuse.org
- Update to version 2.36.6:
  + jpeg: Support the EXIF tag (bgo#143608).
  + ico: Make option parsing locale-independent (bgo#776990).
  + Fix build on Windows.
  + Updated translations.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 2.36.5:
  + Fix mimetypes for thumbnailer (bgo#778451).
  + Handle fseek failure (bgo#776990).
  + Fix signed/unsigned handling (bgo#777374).
  + Fix an overflow check (bgo#777315).
  + Handle extreme scaling better (bgo#80925).
  + Updated translations.
* Mon Jan 16 2017 zaitor@opensuse.org
- Update to version 2.36.4:
  + Add a fastpath for no-op scales.
  + Documentation improvements (bgo#442452).
  + Fix some coverity warnings (bgo#776945, bgo#768062).
  + Updated translations.
* Wed Jan  4 2017 zaitor@opensuse.org
- Update to version 2.36.3:
  + gif, ico: Fix area-updated coordinates (bgo#581484).
  + tga: Improve error handling (bgo#575217).
  + jasper: Improve error handling (bgo#685543).
  + Test suite improvements (bgo#696331).
  + Minor documentation fixes (bgo#776457).
  + Updated translations.
* Tue Dec 20 2016 zaitor@opensuse.org
- Update to version 2.36.2:
  + Fix a NULL pointer dereference (bgo#776026).
  + Fix a memory leak (bgo#776020).
  + Support bmp headers with bitmask (bgo#766890).
  + Add tests for scaling (bgo#80925).
  + Handle compressed pixdata in resources (bgo#776105).
  + Avoid a buffer overrun in the qtif loader (bgo#775648).
  + Fix a crash in the bmp loader (bgo#775242).
  + Fix crash opening pnm images with large dimensions
    (bgo#775232).
  + Prevent buffer overflow in the pixdata loader (bgo#775693).
  + Updated translations.
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 2.36.1:
  + Remove the pixdata loader (bgo#776004).
  + Fix integer overflows in the jpeg loader (bgo#775218).
  + Add an external thumbnailer for images.
  + Updated translations.
- Split the external thumbnailer into gdk-pixbuf-thumbnailer.
* Fri Dec  9 2016 mstaudt@suse.com
- Add u_contrib-gdk-pixbuf-xlib-Fix-rgb888amsb.patch:
  Fix RGBA conversion for big endian X11 environments.
  Fixes (boo#929462, bsc#1010497, bgo#775896).
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 2.36.0:
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 2.35.5:
  + Fix undefined behavior in overflow checks (bgo#770986).
  + Fix a typo (bgo#770756).
  + Avoid segfault in some tests (bgo#771026).
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 2.35.4:
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Escape some macros in comments to silence rpmlint.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 2.35.3:
  + Add API to determine supported save options (bgo#683371).
  + Add helper API for pixbuf options (bgo#768043).
  + Fix invalid gettext use (bgo#758552).
  + Fix a compiler warning in the xpm loader (bgo#768042).
  + Fix integer overflows in the bmp loader (bgo#768688,
    bgo#768738).
  + Fix a crash in the ico loader (bgo#769170).
  + Updated translations.
- Drop gdk-pixbuf-bgo768688-bmp-overflow.patch,
  gdk-pixbuf-bgo768484-ico-set-errors.patch,
  gdk-pixbuf-bgo769738-bmp-overflow.patch and
  gdk-pixbuf-bgo769170-ico-headers.patch: Fixed upstream.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 2.35.2:
  + Use compiler directives for exporting symbols (bgo#767164).
  + Fix a problem with nearest scaling (bgo#766842).
  + Avoid redundant property notification.
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 2.35.1:
  + Add non-varargs variant to save to stream (bgo#683063).
  + Add a common autotools module (bgo#765034).
  + Updated translations.
* Tue Aug 30 2016 mgorse@suse.com
- Add fixes for some crashes, taken from upstream git (bsc#988745
  bsc#991450 CVE-2016-6352):
  gdk-pixbuf-bgo768688-bmp-overflow.patch
  gdk-pixbuf-bgo768484-ico-set-errors.patch
  gdk-pixbuf-bgo769738-bmp-overflow.patch
  gdk-pixbuf-bgo769170-ico-headers.patch
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstreamed patches: gdk-pixbuf-bgo758991.patch,
  0001-pixops-Don-t-overflow-variables-when-shifting-them.patch,
  gdk-pixbuf-bgo747605.patch, gdk-pixbuf-bgo752297.patch,
  0001-ico-Protect-against-overflow.patch,
  0001-pixops-use-gint64-in-more-places-to-avoid-overflow-w.patch,
  gdk-pixbuf-bsc960155-divide-by-zero.patch,
  gdk-pixbuf-bsc948790-tga-dos.patch and
  gdk-pixbuf-2-32-overflow-fixes.patch.
* Fri Mar 25 2016 zaitor@opensuse.org
- Update to version 2.34.0:
  + Don't force no static builds on Win32 (bgo#760369).
  + Updated translations.
* Mon Jan  4 2016 mgorse@suse.com
- Add gdk-pixbuf-bsc960155-divide-by-zero.patch -- fix a possible
  divide by zero (bsc#960155).
- Add gdk-pixbuf-2-32-overflow-fixes.patch,
  0001-ico-Protect-against-overflow.patch,
  gdk-pixbuf-bgo747605.patch, and gdk-pixbuf-bgo758991.patch:
  fix various overflows (bsc#958963 CVE-2015-7552).
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 2.33.2:
  + Fix two crashes in the bmp loader (bgo#747605, bgo#758991).
  + Updated translations.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 2.33.1:
  + Improve various tests.
  + ico: integer overflow fixes.
  + tga: rewrite the loader, introducing a buffer queue
    abstraction.
  + gif: fix thumbnailing animations.
  + Updated translations.
* Mon Dec 21 2015 mgorse@suse.com
- Update to version 2.32.3:
  + Fix two crashes in the bmp loader (bgo#747605, bgo#758991).
  + ico: integer overflow fixes.
  + Updated translations.
* Wed Nov 25 2015 mgorse@suse.com
- Add
  0001-pixops-use-gint64-in-more-places-to-avoid-overflow-w.patch:
  Fix some more overflows scaling a gif (bsc#948791 CVE-2015-7673).
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 2.32.2:
  + Avoid some integer overflow possibilities in scaling code.
  + Updated translations.
* Mon Oct  5 2015 mgorse@suse.com
- Add gdk-pixbuf-bsc948790-tga-dos.patch: fix an overflow and DoS
  with a TGA (bsc#948790 CVE-2015-7673).
- Add
  0001-pixops-Don-t-overflow-variables-when-shifting-them.patch: Fix
  overflow when scaling a gif (bsc#948791 CVE-2015-7674).
* Fri Sep 25 2015 zaitor@opensuse.org
- Update to version 2.32.1:
  + Make relocations optional.
  + Fix a crash due to overflow when scaling.
  + Drop loaders for some rare image formats: wbmp, ras, pcx.
  + Prevent testsuite failures due to lack of memory.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 2.32.0:
  + Fix build issues (bgo#754154).
  + Fix animation loading (bgo#755269).
  + More overflow fixes in the scaling code (bgo#754387).
  + Fix a crash in the tga loader.
  + Updated translations.
* Mon Sep 14 2015 mgorse@suse.com
- Add gdk-pixbuf-bgo752297.patch: Check for overflow before
  allocating memory when scaling (bsc#942801 CVE-2015-4491).
  Taken from upstream.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 2.31.7:
  + Fix several integer overflows (bgo#753908, bgo#753569).
  + Fix build failure with --disable-modules (bgo#740912).
  + Port animations to GTask.
  + Updated translations.
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 2.31.6:
  + Really fix bgo#752297. This is CVE-2015-4491.
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 2.31.5:
  + Add support for g_autoptr for all object types (bgo#750497).
  + Avoid a possible divide-by-zero in the pixbuf loader
    (bgo#750440).
  + Remove gettext .pot file hack (bgo#743574).
  + Be more careful about integer overflow (bgo#752297).
  + Updated translations.
- Drop README from docs as it is now empty.
- Add generic www.gnome.org URL to silence a few lint warnings.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 2.31.4:
  + SVGZ icons in notification GNOME3 (bgo#648815).
  + gdk_pixbuf_apply_embedded_orientation is not working
    (bgo#725582).
  + Updated translations.
* Sun Mar  8 2015 zaitor@opensuse.org
- Update to version 2.31.3:
  + API changes: Revert an annotation change that broke bindings.
  + Build fixes:
  - Clean up configure
  - Fix Visual Studio build
  - Define MAP_ANONYMOUS when needed
  - Include gi18n-lib.h where needed
  + Updated translations.
* Sat Nov 22 2014 zaitor@opensuse.org
- Update to version 2.31.2:
  + API changes:
  - Deprecate GdkPixdata.
  - Add gdk_pixbuf_get_options() helper to list set options.
  - Annotations fixes for various functions.
  - Remove incorrect info about area-prepared signal.
  + Image format support changes:
  - Flag multi-page TIFF files.
  - Fix memory usage for GIF animations, add note about minimum
    frame length.
  - Return an error for truncated PNG files.
  - Add density (DPI) support for JPEG, PNG and TIFF.
  - Fix reading CMYK JPEG files generated by Photoshop.
  - Allow saving 1-bit mono TIFF files as used in faxes.
  - Simplify loader names.
  - Fix loading GIF files when the first write is short.
  - Add progressive loading to ICNS files.
  - Add support for 256x256 ICO files.
  - Fix reading MS AMCap2 BMP files.
  + Other:
  - Honour requested depth in Xlib.
  - Special-case compositing/copying with no scaling.
  - Add relocation support to OSX and Linux.
  - Prefer gdk-pixbuf's loaders to the GDI+ ones on Windows.
* Sun Nov  9 2014 ledest@gmail.com
- fix bashism in post script
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 2.31.1:
  + Add gdk_pixbuf_get_file_info_async.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 2.31.0:
  + To improve the situation for language bindings, pixbufs can now
    be constructed from data in GBytes, and pixbuf data can also be
    extracted in this form. The GBytes data is treated as readonly,
    and gdk_pixbuf_get_pixels() will create a copy. To avoid this
    copy, a new function gdk_pixbuf_read_pixels() was introduced
    which returns a const pointer to the data without copying.
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 2.30.8:
  + Add missing nullability annotations.
  + Documentation improvements.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 2.30.7:
  + Documentation fixes.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 2.30.6:
  + Add annotations to gdk_pixbuf_save_to_buffer.
  + Win32 build fixes.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 2.30.5:
  + Convert documentation to markdown.
  + Updated translations.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 2.30.4:
  + Make test suite robust against disabled formats.
  + Fix test failure when using libpng without iTXt support.
  + Updated translations.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 2.30.3:
  + Expand the test suite.
  + Enable coverage testing with --enable-coverage.
  + Unify sniff buffer sizes across loaders: 4k everywhere.
  + Port to GTask (bgo#712704).
  + xpm: Fix scaling (bgo#686514).
  + xpm: Update colors from pango (bgo#678996).
  + qtif: fix fread() error check (bgo#721371).
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 2.30.2:
  + jpeg: fix icc profile loading and improve error handling.
  + Make --update-cache work better.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 2.30.1:
  + Only use RLIMIT_AS when available (bgo#708666).
  + Only use setrlimit when available (bgo#710690).
  + Avoid a bashism (bgo#711600).
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 2.30.0:
  + Visual C++ build fixes.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.29.3:
  + Use GLib setup for installed tests.
  + Make installed tests find data files.
  + Updated translations.
* Sat Jun 22 2013 dimstar@opensuse.org
- Update to version 2.29.2:
  + Install some tests.
  + ANI: Set an error if we fail to produce an animation.
  + Updated translations.
* Sun May  5 2013 zaitor@opensuse.org
- Update to version 2.29.0:
  + Add gdk_pixbuf_loader_write_bytes (bgo#696917).
  + Update GIcon implementation (bgo#688820).
  + Fix libpng linking issues (bgo#698093).
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 2.28.1:
  + Fix build with libpng 1.6.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 2.27.3:
  + Allow prepare_func call in stop_load (bgo#695228).
  + Updated translations.
* Sun Mar  3 2013 zaitor@opensuse.org
- Update to version 2.27.2:
  + Make gdk_pixbuf_animation_new_from_file load png files
    (bgo#694148).
  + Fix string formatting for l10n extraction (bgo#693534).
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 2.27.1:
  + Allow loading animations from streams.
  + Allow loading animations from resources.
  + Fix cross-compiling for Windows and Wine (bgo#692072).
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 2.27.0:
  + The broken locking mechanism for loaders has been removed.
* Wed Nov 21 2012 dimstar@opensuse.org
- Do not provide typelib-1_0-GdkPixbuf-2_0-32bit (baselibs.conf):
  this only results in a big mess of duplicate provides. Adding
  ($HOSTTYPE) to the typelib() symbols does not work, as we'd
  otherwise no longer be able to use them against noarch packages.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 2.26.5:
  + Improve error message for missing cache file (bgo#686844).
  + Ensure we link to gobject (bgo#686822).
  + Silence custom make rule (bgo#686605).
  + Prevent an error pileup (bgo#686139).
  + Don't use AC_PATH_PROG (bgo#671516).
  + Updated translations.
- Drop gdk-pixbuf-link-gobject.patch: fixed upstream.
* Thu Oct 25 2012 dimstar@opensuse.org
- Add gdk-pixbuf-link-gobject.patch: Ensure to link against
  libgobject.
* Wed Oct 24 2012 jengelh@inai.de
- Make gdk-pixbuf-devel-32bit available on all archs
  (baselibs.conf).
* Tue Sep 18 2012 zaitor@opensuse.org
- Update to version 2.26.4:
  + Make tiff loader threadsafe.
  + Support saving ICC profiles in jpeg (bgo#604610).
  + Add some missing annotations (bgo#683064).
  + Documentation improvements (bgo#676430).
  + Updated translations.
- Clean up spec, remove source service checkout support.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 2.26.3:
  + Fix a minor string leak (bgo#681943)
  + Bail out as soon as a module is found (bgo#681943)
  + Add an option to disable GIO mime detection (bgo#676726)
  + Updated translations.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 2.26.2:
  + Various functions have been added to the docs
  + Fix introspection of gdk_pixbuf_new_from_xpm_data (bg0#668956)
  + Improve the gif loaders handling of animations with varying
    frame sizes (bgo#613595)
  + Updated translatons.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 2.26.1:
  + Fix srcdir != builddir build (bgo#672133)
  + Avoid an integer overflow in the xbm loader (bgo#672811)
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 2.26.0:
  + Correctly load .ANI files without sequence chunks.
  + Win32 build fixes.
  + Updated translations.
* Tue Feb  7 2012 vuntz@opensuse.org
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Sun Feb  5 2012 zaitor@opensuse.org
- Update to version 2.25.2:
  + New functions to load pixbufs from resources:
    gdk_pixbuf_new_from_resource,
    gdk_pixbuf_new_from_resource_at_scale.
  + gdk-pixbuf-pixdata is a new program that generates raw binary
    GdkPixdata files, and there is a new loader for these.
  + Updated translations.
- Drop gdk-pixbuf-missing-include.patch: fixed upstream.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 2.25.0:
  + Fix some string problems in the qtif loader (bgo#629396)
  + Fix various introspection annotations (bgo#659888)
  + Fix introspectability of gdk_pixbuf_get_pixels (bgo#662009)
  + Skip compressed icons in ICOs (bgo#652498)
  + Fix thread-safety issues with animations
  + Fix gif animation delays between frames (bgo#655755)
  + Work around gtk-doc limitations (bgo#663554)
  + Add a --with-x11 configure options (bgo#657569)
  + Fix build problem on NetBSD (bgo#640405)
  + Fix mingw build (bgo#657876)
  + Updated translations.
- Add gdk-pixbuf-missing-include.patch: add missing include.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Pass new --with-x11 option to configure.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file in typelib-1_0-GdkPixbuf-2_0 subpackage.
- Add typelib-1_0-GdkPixbuf-2_0 Requires to devel subpackage.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.24.0:
  + Clean up dependencies in the .pc file
  + Win32 build fixes
  + Updated translations.
* Tue Jun 28 2011 dimstar@opensuse.org
- Update to version 2.23.5:
  + Prevent the return of partically initialized pixbuf structures
    from the gif loader in some error cases (CVE-2011-2485)
  + Win32 build updates.
* Tue Jun 14 2011 vuntz@opensuse.org
- Update to version 2.23.4:
  + Drop use of G_CONST_RETURN
  + Win32 build fixes
  + Updated translations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.23.3:
  + Fix release tarball
  + More win32 build fixes
- Changes from version 2.23.2:
  + bgo#636138: Fix possible crashes when loading jpegs
  + Introspection annotation fixes
  + Update build files on Win32
  + Updated translations.
* Mon Mar  7 2011 fcrozat@novell.com
- Update to version 2.23.1:
  + Introspection:
  - Add package information
  - Don't include backend API
  + Fix build against libpng 1.5
  + Bugs fixed:
  - bgo#634659: gdk-pixbuf 2.22 can't find localisation
  - bgo#635364: Add C include and exported packages information
    to GIR
  - bgo#639922: Proposed Visual C++ 2008 Project Files
  - bgo#640407: Unportable test(1) construct in configure script.
  + Updated translations.
* Wed Feb 16 2011 fcrozat@novell.com
- Update to version 2.23.0:
  + New API: gdk_pixbuf_new_from_stream_async
  + Updated translations.
- Drop gdk-pixbuf-add-gir_PACKAGES.patch: fixed upstream. Also
  remove gnome-common BuildRequires and call to gnome-autogen.sh
  that were needed for the patch.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gtk-doc BuildRequires.
  + Add call to ./autogen.sh.
  + Enforce gtk-doc html generation by passing --enable-gtk-doc to
    configure.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Dec 28 2010 dimstar@opensuse.org
- Add gdk-pixbuf-add-gir_PACKAGES.patch: vapigen 0.12 parses the
  .gir and the .vapi file, complaining about duplicate definitions.
  The error is seen in packages building against gdk-pixbuf and
  using vala-unstable to create own vala bindings.
- Add gnome-common BuildRequires, because the patch touches
  Makefile.am, and call to gnome-autogen.sh in the build section.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 2.22.1:
  + Make GdkPixbuf implement the GIcon interface
  + Fix loader.cache detection on Windows
  + Updated translations.
* Wed Oct 13 2010 vuntz@opensuse.org
- Put comments that are in the scriptlets area of the spec file in
  "%%if 0" statement: if we don't do that, they actually end up in
  the scriplets and can even make them fail if the scriptlets were
  just "-p /sbin/ldconfig".
* Mon Oct 11 2010 vuntz@opensuse.org
- Remove gdk-pixbuf-query-loaders Requires(postun) in
  libgdk_pixbuf-2_0-0: it's not needed.
- Add missing Requires for gdk-pixbuf-query-loaders to
  libgdk_pixbuf-2_0-0 in baselibs.conf.
- Update baselibs.conf to remove assumption in the scriptlets of
  the generated packages that they are 32bit packages.
- Use <prefix> in baselibs.conf since we use full paths there, and
  this is needed for x86 packages that put files in
  /emul/ia32-linux.
* Tue Sep 21 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Fix a problem with mime type detection
  + Win32: Fix linking on x64
  + Drop gobject-introspection requirement to 0.9.3
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update the %%post scriptlet to not fail if
  gdk-pixbuf-query-loaders is not installed. Also make it easier to
  read by using a %%define to use the right binary for
  gdk-pixbuf-query-loaders.
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 2.21.7:
  + bgo#624712: Fix linking when libpng loader is builtin
  + bgo#604284: Improve the pixbuf loader docs
  + bgo#622940: Fix compat issues wrt to single includes
  + Win32: Link directly to GDI+
  + Require gobject-introspection 0.9.5
  + Updated translations.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.21.6:
  + Drop aliasing hacks, use -Bsymbolic-functions
  + Support NOCONFIGURE in autogen.sh
  + Check for different versions of libpng
* Wed Jul 21 2010 vuntz@opensuse.org
- Improve summaries and descriptions.
- Change gobject-introspection-devel and libpng-devel BuildRequires
  to pkgconfig(gobject-introspection-1.0) and pkgconfig(libpng).
- Add libjasper-devel, pkgconfig(x11) BuildRequires, and explicit
  libjpeg-devel.
- Add baselibs.conf, and rename gdk-pixbuf-query-loaders on 64
  bits.
- Make libgdk_pixbuf-2_0-0 provide gdk-pixbuf to make the lang
  package installable.
- Add Recommends for the lang package to libgdk_pixbuf-2_0-0.
- Move conflicts with gtk2 < 2.21 to libgdk_pixbuf-2_0-0.
- Stop renaming gdk-pixbuf-query-loaders to
  gdk-pixbuf-query-loaders-2.0: they're no issue with parallel
  instability since there's no other such tool.
- Touch %%{_libdir}/gdk-pixbuf-2.0/2.10.0/loaders.cache and make it
  a ghost file.
- Pass --disable-static and --with-libjasper to configure.
- Enable parallel build.
- Move gtk-doc documentation and gdk-pixbuf-csource to devel
  subpackage.
- Add a macros.gdk-pixbuf file containing useful macros for
  packages that ship gdk-pixbuf loaders.
* Tue Jul  6 2010 dimstar@opensuse.org
- Initial package of gdk-pixbuf, which has been split out of gtk2
  main package. For this reason it conflicts with gtk < 2.21
- Changes from version 2.21.5:
  + Bring back deprecated API
  + Allow including individual headers again
- Changes from version 2.21.4:
  + Drop -2.0 suffix on gdk-pixbuf-csource and
    gdk-pixbuf-query-loaders
  + Include gdk-pixbuf-xlib again
  + Add pixbuf tests from the GTK+ tree
  + Add binary version and module dir as variables in the .pc file
  + Add a boxed type for GdkPixbufFormat
- Changes from version 2.21.3, since GTK+ 2.21.2:
  + gdk-pixbuf has been turned back into a standalone library.
  + The default location for loaders has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders
  + The default location for the module file has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders.cache
    and gdk-pixbuf-query-loaders-2.0 will update that file when
    given the --update-cache option.
